@@ -1,9 +1,10 @@
-#include "java/lang/String.h"
 #include "sdl4gcj/video/Screen.h"
 #include "sdl4gcj/video/VideoInfo.h"
 #include "sdl4gcj/video/Rect.h"
 #include "sdl4gcj/SDLException.h"
 
+#include <java/lang/String.h>
+
 #include <stdlib.h>
 #include <gcj/cni.h>
 #include <SDL.h>
