@@ -311,7 +311,7 @@ public class Surface implements VideoConstants
 	* Convert a surface to the display format.
 	* SDL_DisplayFormatAlpha() wrapper.
 	**/
-	public native void displayForamtAlpha();
+	public native void displayFormatAlpha();
 
 	/**
 	* Converts a surface to the same format as another surface.
@@ -340,7 +340,25 @@ public class Surface implements VideoConstants
 	* Sets the colors in the palette of an 8-bit surface.
 	* SDL_SetPalette() wrapper.
 	**/
-	public native void setPalette(Palette palette);
+	public void setPalette(Palette palette)
+	{
+		this.setPalette(palette, 0, 0, palette.getSize());
+	}
+
+	/**
+	* Sets the colors in the palette of an 8-bit surface.
+	* SDL_SetPalette() wrapper.
+	**/
+	public void setPalette(Palette palette, int index)
+	{
+		this.setPalette(palette, index, 0, palette.getSize());
+	}
+
+	/**
+	* Sets the colors in the palette of an 8-bit surface.
+	* SDL_SetPalette() wrapper.
+	**/
+	public native void setPalette(Palette palette, int index, int firstcolor, int ncolors);
 
 	/**
 	* Gets palette.
