@@ -154,9 +154,9 @@ public class CursorTest implements SDLConstants
 						break;
 					case SDL_MOUSEBUTTONUP :
 						if (event.buttonup.button == SDL_BUTTON_LEFT)
-							screen.showCursor(true);
+							screen.setCursorVisible(true);
 						else if (event.buttonup.button == SDL_BUTTON_RIGHT)
-							screen.showCursor(false);
+							screen.setCursorVisible(false);
 						break;
 					case SDL_KEYDOWN :
 						if ((event.keydown.sym == SDLK_ESCAPE) ||
