@@ -22,6 +22,9 @@ public class Test implements SDLConstants
 		else
 			System.out.println("SDLSystem.byteOrder() : SDL_BIG_ENDIAN = " + SDLSystem.byteOrder());
 
+		int bpp = Screen.videoModeOK(640, 480, 32, SDL_SWSURFACE);
+		System.out.println("Screen.videoModeOK(640, 480, 32, SDL_SWSURFACE) : " + bpp);
+
 		Screen.setCaption("Window Caption", "Icon Caption");
 		System.out.println("windowCaption : '" + Screen.getWindowCaption() + "'");
 		System.out.println("iconCaption   : '" + Screen.getIconCaption() + "'");
@@ -44,7 +47,7 @@ public class Test implements SDLConstants
 
 		try
 		{
-			Screen screen = Screen.setVideoMode(640, 480, 32, SDL_SWSURFACE|SDL_ANYFORMAT);
+			Screen screen = Screen.setVideoMode(640, 480, bpp, SDL_SWSURFACE|SDL_ANYFORMAT);
 			Surface memory = screen.cloneSurface();
 
 			int bgPixel = screen.mapRGB(Color.BLACK);
