@@ -75,7 +75,7 @@ public class TimerAnimation implements SDLConstants
 {
 	public static void main(String[] args)
 	{
-		if (Sys.init(SDL_INIT_VIDEO) != 0)
+		if (SDLSystem.init(SDL_INIT_VIDEO) != 0)
 		{
 			System.out.println("Init() fail");
 			System.exit(0);
@@ -136,7 +136,7 @@ public class TimerAnimation implements SDLConstants
 				screen.fillRect(bgPixel);
 				blueman.paint(screen);
 				screen.updateRect(blueman);
-				Sys.delay(30);
+				SDLSystem.delay(30);
 			}
 
 		}
@@ -146,7 +146,7 @@ public class TimerAnimation implements SDLConstants
 		}
 		finally
 		{
-			Sys.quit();
+			SDLSystem.quit();
 		}
 	}
 }
